==> pegasus-merchandise-api-1.4.16-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsSearchSuggestVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.sun.tools.javac.util.Convert;


import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Created by gensheng.ye on 2017/12/29.
 */

public class PsSearchSuggestVO  implements Serializable {

    private Long id;
    private String keywordCn;
    private String keywordEn;
    private String keywordPinyin;
    private String keywordPy;
    private String keywordType;
    private Integer resultCount;
    private BigDecimal wordFrequency;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getKeywordCn() {
        return keywordCn;
    }

    public void setKeywordCn(String keywordCn) {
        this.keywordCn = keywordCn;
    }

    public String getKeywordEn() {
        return keywordEn;
    }

    public void setKeywordEn(String keywordEn) {
        this.keywordEn = keywordEn;
    }

    public String getKeywordPinyin() {
        return keywordPinyin;
    }

    public void setKeywordPinyin(String keywordPinyin) {
        this.keywordPinyin = keywordPinyin;
    }

    public String getKeywordPy() {
        return keywordPy;
    }

    public void setKeywordPy(String keywordPy) {
        this.keywordPy = keywordPy;
    }

    public String getKeywordType() {
        return keywordType;
    }

    public void setKeywordType(String keywordType) {
        this.keywordType = keywordType;
    }

    public Integer getResultCount() {
        return resultCount;
    }

    public void setResultCount(Integer resultCount) {
        this.resultCount = resultCount;
    }

    public BigDecimal getWordFrequency() {
        return wordFrequency;
    }

    public void setWordFrequency(BigDecimal wordFrequency) {
        this.wordFrequency = wordFrequency;
    }

    @Override
    public String toString() {
       return "id=" + id +
               ",keywordCn=" + keywordCn +
               ",keywordEn=" + keywordEn +
               ",keywordPinyin=" + keywordPinyin +
               ",keywordPy=" + keywordPy +
               ",keywordType=" + keywordType +
               ",resultCount=" + resultCount +
               ",wordFrequency=" + wordFrequency;

    }
}

==> pegasus-merchandise-api-2.5.2-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsSearchSuggestVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Created by gensheng.ye on 2017/12/29.
 */
public class PsSearchSuggestVO  implements Serializable {

    /**
	 * @Field long serialVersionUID 
	 */
	private static final long serialVersionUID = 1L;
	private Long id;
    private String keywordCn;
    private String keywordEn;
    private String keywordPinyin;
    private String keywordPy;
    private String keywordType;
    private Integer resultCount;
    private BigDecimal wordFrequency;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getKeywordCn() {
        return keywordCn;
    }

    public void setKeywordCn(String keywordCn) {
        this.keywordCn = keywordCn;
    }

    public String getKeywordEn() {
        return keywordEn;
    }

    public void setKeywordEn(String keywordEn) {
        this.keywordEn = keywordEn;
    }

    public String getKeywordPinyin() {
        return keywordPinyin;
    }

    public void setKeywordPinyin(String keywordPinyin) {
        this.keywordPinyin = keywordPinyin;
    }

    public String getKeywordPy() {
        return keywordPy;
    }

    public void setKeywordPy(String keywordPy) {
        this.keywordPy = keywordPy;
    }

    public String getKeywordType() {
        return keywordType;
    }

    public void setKeywordType(String keywordType) {
        this.keywordType = keywordType;
    }

    public Integer getResultCount() {
        return resultCount;
    }

    public void setResultCount(Integer resultCount) {
        this.resultCount = resultCount;
    }

    public BigDecimal getWordFrequency() {
        return wordFrequency;
    }

    public void setWordFrequency(BigDecimal wordFrequency) {
        this.wordFrequency = wordFrequency;
    }

    @Override
    public String toString() {
       return "id=" + id +
               ",keywordCn=" + keywordCn +
               ",keywordEn=" + keywordEn +
               ",keywordPinyin=" + keywordPinyin +
               ",keywordPy=" + keywordPy +
               ",keywordType=" + keywordType +
               ",resultCount=" + resultCount +
               ",wordFrequency=" + wordFrequency;

    }
}
